@@ -14,6 +14,7 @@ type Config struct {
 	Interface           string   `json:"interface"`
 	Port                int      `json:"port"`
 	Directory           string   `json:"directory"`
+	UploadFolder        string   `json:"upload_folder"`
 	SSL                 bool     `json:"ssl"`
 	SelfSigned          bool     `json:"self_signed"`
 	PrivateKey          string   `json:"private_key"`
@@ -72,6 +73,7 @@ func PrintExample() (string, error) {
 		Interface:           "0.0.0.0",
 		Port:                8000,
 		Directory:           ".",
+		UploadFolder:        ".",
 		SSL:                 false,
 		SelfSigned:          false,
 		PrivateKey:          "",
@@ -121,7 +123,7 @@ func SanityChecks(webroot string, configpath string, AuthPassword string) error
 	if webroot == filepath.Dir(configpath) {
 		logger.Warn("You are hosting your config file in the webroot of goshs. This is not recommended.")
 		// Check if the process user can write the config file
-		file, err := os.OpenFile(configpath, os.O_WRONLY|os.O_APPEND, 0666)
+		file, err := os.OpenFile(configpath, os.O_WRONLY|os.O_APPEND, 0600)
 		if err != nil {
 			return err
 		}
