@@ -7,10 +7,7 @@ import (
 )
 
 func (fs *FileServer) logOnly(w http.ResponseWriter, req *http.Request) {
-	logger.LogRequest(req, http.StatusOK, fs.Verbose)
+	logger.LogRequest(req, http.StatusOK, fs.Verbose, fs.Webhook)
 	w.WriteHeader(200)
 	w.Write([]byte("ok\n"))
-
-	// Send webhook message
-	fs.HandleWebhookSend("", "verbose")
 }
