@@ -34,6 +34,9 @@ func (fs *FileServer) SetupMux(mux *CustomMux, what string) string {
 			mux.Use(fs.BasicAuthMiddleware)
 		}
 
+		// IP Whitelist Middleware
+		mux.Use(fs.IPWhitelistMiddleware)
+
 		// Add custom server header middleware
 		mux.Use(fs.ServerHeaderMiddleware)
 
@@ -52,6 +55,12 @@ func (fs *FileServer) SetupMux(mux *CustomMux, what string) string {
 
 		addr = fmt.Sprintf("%+v:%+v", fs.IP, fs.Port)
 	case "webdav":
+		// IP Whitelist Middleware
+		mux.Use(fs.IPWhitelistMiddleware)
+
+		// Add custom server header middleware
+		mux.Use(fs.ServerHeaderMiddleware)
+
 		wdHandler := &webdav.Handler{
 			FileSystem: webdav.Dir(fs.Webroot),
 			LockSystem: webdav.NewMemLS(),
@@ -67,6 +76,7 @@ func (fs *FileServer) SetupMux(mux *CustomMux, what string) string {
 			},
 		}
 
+		// Check Basic Auth and use middleware
 		if fs.User != "" || fs.Pass != "" {
 			authHandler := fs.BasicAuthMiddleware(wdHandler)
 			mux.Handle("/", authHandler)
@@ -237,6 +247,24 @@ func (fs *FileServer) Start(what string) {
 	// Print all embedded files as info to the console
 	fs.PrintEmbeddedFiles()
 
+	// Create SharedLinks map
+	fs.SharedLinks = make(map[string]SharedLink)
+
+	// Go routine to cleanup SharedLinks when expired
+	go func() {
+		ticker := time.NewTicker(1 * time.Minute)
+		defer ticker.Stop()
+		for range ticker.C {
+			now := time.Now()
+			for token, link := range fs.SharedLinks {
+				if link.Expires.Before(now) {
+					delete(fs.SharedLinks, token)
+					logger.Debugf("Expired shared link removed: %s", token)
+				}
+			}
+		}
+	}()
+
 	// Start listener
 	fs.StartListener(server, what, listener)
 }
